@@ -1,6 +1,6 @@
 package Mozilla::DOM;
 
-# $Id: DOM.pm,v 1.5 2005/04/05 01:52:05 slanning Exp $
+# $Id: DOM.pm,v 1.6 2005/04/06 12:05:36 slanning Exp $
 
 use 5.008;
 use strict;
@@ -10,7 +10,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -177,6 +177,26 @@ our @ISA = qw(Mozilla::DOM::UIEvent);
 
 # -----------------------------------------------------------------------------
 
+package Mozilla::DOM::MutationEvent;
+
+our @ISA = qw(Mozilla::DOM::Event Exporter);
+
+use constant MODIFICATION => 1;
+use constant ADDITION     => 2;
+use constant REMOVAL      => 3;
+
+our %EXPORT_TAGS = (
+    changes => [qw(
+        MODIFICATION
+	ADDITION
+	REMOVAL
+    )],
+);
+our @EXPORT_OK = map { @$_ } values(%EXPORT_TAGS);
+$EXPORT_TAGS{all} = \@EXPORT_OK;
+
+# -----------------------------------------------------------------------------
+
 package Mozilla::DOM::Document;
 
 our @ISA = qw(Mozilla::DOM::Node);
@@ -245,7 +265,39 @@ our @ISA = qw(Mozilla::DOM::Node);
 
 package Mozilla::DOM::Node;
 
-# just to quiet down Glib::GenPod
+our @ISA = qw(Exporter);
+
+use constant ELEMENT_NODE                => 1;
+use constant ATTRIBUTE_NODE              => 2;
+use constant TEXT_NODE                   => 3;
+use constant CDATA_SECTION_NODE          => 4;
+use constant ENTITY_REFERENCE_NODE       => 5;
+use constant ENTITY_NODE                 => 6;
+use constant PROCESSING_INSTRUCTION_NODE => 7;
+use constant COMMENT_NODE                => 8;
+use constant DOCUMENT_NODE               => 9;
+use constant DOCUMENT_TYPE_NODE          => 10;
+use constant DOCUMENT_FRAGMENT_NODE      => 11;
+use constant NOTATION_NODE               => 12;
+
+our %EXPORT_TAGS = (
+    types => [qw(
+        ELEMENT_NODE
+        ATTRIBUTE_NODE
+        TEXT_NODE
+        CDATA_SECTION_NODE
+        ENTITY_REFERENCE_NODE
+        ENTITY_NODE
+        PROCESSING_INSTRUCTION_NODE
+        COMMENT_NODE
+        DOCUMENT_NODE
+        DOCUMENT_TYPE_NODE
+        DOCUMENT_FRAGMENT_NODE
+        NOTATION_NODE
+    )],
+);
+our @EXPORT_OK = map { @$_ } values(%EXPORT_TAGS);
+$EXPORT_TAGS{all} = \@EXPORT_OK;
 
 # -----------------------------------------------------------------------------
 
